==> imwiki-0.6.1.tar.gz: imwiki-0.6.1/imLib/Revision.py <==
# -*- coding: utf8 -*-
import os
import fnmatch
import Repository
import utils
import Page
import Permission 

from WikiException import WikiException
class NotExistRevision(WikiException): pass

def getRevTimeStampList(categoryPath, pageName):
		fnameList = os.listdir(os.path.join(Repository.getBackupRepository(), utils.encode(categoryPath)))
		fnameList = fnmatch.filter(fnameList, utils.encode(pageName)+'.*')
		timeStampList = map(lambda fname: fname[-10:], fnameList)
		timeStampList.sort()
		return timeStampList

def getLastTimeStamp(categoryPath, pageName):
	timeStampList = getRevTimeStampList(categoryPath, pageName)
	if timeStampList:
		return int(timeStampList[-1])
	return None

class Revision:
	def __init__(self, categoryPath, pageName, timeStamp):
		self.pageName = pageName
		self.categoryPath = categoryPath
		self.encPageName = utils.encode(pageName)
		try:
			self.timeStamp = int(timeStamp)
		except ValueError:
			raise NotExistRevision
		self.filePath = os.path.join(Repository.getBackupRepository(), utils.encode(categoryPath), self.encPageName+'.'+str(self.timeStamp))
		if not self.pageName or not os.path.exists(self.filePath):
			raise NotExistRevision
		self.load()

	def load(self):
		fp = file(self.filePath, 'rb')
		s = fp.readline().strip()
		self.perms = Permission.Permission(s)
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self.loadCurPerm()

	def loadCurPerm(self):
		page = Page.getPage(self.categoryPath, self.pageName)
		if page:
			self.curPerms = page.perms
			return
		timeStamp = getLastTimeStamp(self.categoryPath, self.pageName)
		if timeStamp and int(timeStamp) == self.timeStamp:
			self.curPerms = self.perms
			return
		self.curPerms = Revision(self.categoryPath, self.pageName, timeStamp).perms

	def toRawText(self):
		teul = 'Tags : %s\n%s\n%s'
		return teul % (self.tags, '='*(len(self.tags) + 7), self.rawText)

==> imwiki-0.6.2.tar.gz: imwiki-0.6.2/imLib/Revision.py <==
# -*- coding: utf8 -*-
import os
import fnmatch
import Repository
import utils
import Page
import Permission 

from WikiException import WikiException
class NotExistRevision(WikiException): pass

def getRevTimeStampList(categoryPath, pageName):
		fnameList = os.listdir(os.path.join(Repository.getBackupRepository(), utils.encode(categoryPath)))
		fnameList = fnmatch.filter(fnameList, utils.encode(pageName)+'.*')
		timeStampList = map(lambda fname: fname[-10:], fnameList)
		timeStampList.sort()
		return timeStampList

def getLastTimeStamp(categoryPath, pageName):
	timeStampList = getRevTimeStampList(categoryPath, pageName)
	if timeStampList:
		return int(timeStampList[-1])
	return None

class Revision(Permission.PermissionChecker):
	def __init__(self, category, pageName, timeStamp):
		self.pageName = pageName
		self.category = category
		self.encPageName = utils.encode(pageName)
		try:
			self.timeStamp = int(timeStamp)
		except ValueError:
			raise NotExistRevision
		self.filePath = os.path.join(Repository.getBackupRepository(), utils.encode(category.categoryPath), self.encPageName+'.'+str(self.timeStamp))
		if not self.pageName or not os.path.exists(self.filePath):
			raise NotExistRevision
		self.load()

	def load(self):
		fp = file(self.filePath, 'rb')
		s = fp.readline().strip()
		self.revPerms = Permission.Permission(s)
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self.loadPerms()
	def getGroup(self):
		return self.category.group
	def loadPerms(self):
		page = Page.getPage(self.category.categoryPath, self.pageName)
		if page:
			self.perms = page.perms
			return
		timeStamp = getLastTimeStamp(self.category.categoryPath, self.pageName)
		if timeStamp and int(timeStamp) == self.timeStamp:
			self.perms = self.revPerms
			return
		self.perms = Revision(self.category, self.pageName, timeStamp).revPerms

	def toRawText(self):
		teul = 'Tags : %s\n%s\n%s'
		return teul % (self.tags, '='*(len(self.tags) + 7), self.rawText)
